==> apeman-dev-commons-releasing-1.1.7.tgz: package/lib/release.js <==
/**
 * Release a package.
 * @memberof module:apeman-dev-commons-releasing/lib
 * @function release
 * @param {string[]} scripts - Scripts to run.
 * @param {object} options - Optional settings.
 * @param {function} callback - Callback when done.
 */

"use strict";

var async = require('async'),
    argx = require('argx'),
    colorprint = require('colorprint'),
    resolveScript = require('./resolve_script'),
    ifSure = require('./if_sure'),
    execcli = require('execcli');

/** @lends release */
function release(scripts, options, callback) {
    release.ifSure(function () {
        var args = argx(arguments);
        callback = args.pop('function') || argx.noop;
        options = args.pop('object') || {};
        colorprint.notice('Start releasing...');
        async.series([
            function (callback) {
                async.eachSeries(scripts, function (script, callback) {
                    script = script.split(/\s/g).map(function (word) {
                        return word.replace(/\\s/g, ' ');
                    });
                    script[0] = resolveScript(script[0]);
                    colorprint.info('$ ' + script.join(' '));
                    execcli.apply(execcli, script.concat({}).concat(options).concat(callback));
                }, callback);
            }
        ], function (err) {
            release.done(err, true);
            callback(err)
        });
    });
}
release.ifSure = ifSure;
release.resolveScript = resolveScript;
release.done = function (err, exit) {
    process.nextTick(function () {
        if (err) {
            colorprint.error(err);
        } else {
            colorprint.notice('...releasing done!');
        }
        if (exit) {
            process.exit(err ? 1 : 0);
        }
    });
};

module.exports = release;

==> apeman-dev-commons-releasing-1.1.14.tgz: package/lib/release.js <==
/**
 * Release a package.
 * @memberof module:apeman-dev-commons-releasing/lib
 * @function release
 * @param {string[]} scripts - Scripts to run.
 * @param {object} options - Optional settings.
 * @param {function} callback - Callback when done.
 */

"use strict";

var async = require('async'),
    argx = require('argx'),
    colorprint = require('colorprint'),
    resolveScript = require('./resolve_script'),
    ifSure = require('./if_sure'),
    execcli = require('execcli');

/** @lends release */
function release(scripts, options, callback) {
    release.ifSure(function () {
        var args = argx(arguments);
        callback = args.pop('function') || argx.noop;
        options = args.pop('object') || {};
        colorprint.notice('Releasing started...');
        async.series([
            function (callback) {
                async.eachSeries(scripts, function (script, callback) {
                    script = script.split(/\s/g).map(function (word) {
                        return word.replace(/\\s/g, ' ');
                    });
                    script[0] = resolveScript(script[0]);
                    colorprint.info('$ ' + script.join(' '));
                    execcli.apply(execcli, script.concat({}).concat(options).concat(callback));
                }, callback);
            }
        ], function (err) {
            release.done(err, true);
            callback(err)
        });
    });
}
release.ifSure = ifSure;
release.resolveScript = resolveScript;
release.done = function (err, exit) {
    process.nextTick(function () {
        if (err) {
            colorprint.error(err);
        } else {
            colorprint.notice('...releasing done!');
        }
        if (exit) {
            process.exit(err ? 1 : 0);
        }
    });
};

module.exports = release;
